class Config:
	def __init__(self, timeout: int, cookiefile: str, username: str, password: str):
		self.timeout = timeout
		self.cookiefile = cookiefile
		self.username = username
		self.password = password
